@@ -6,3 +6,7 @@
 #'
 #' @export
 can_be_numeric <- strex::str_can_be_numeric
+
+#' @rdname can_be_numeric
+#' @export
+str_can_be_numeric <- can_be_numeric
